import HomeIcon from '@mui/icons-material/Home';
import MonitoringIcon from '@mui/icons-material/Dvr';
import ReportingIcon from '@mui/icons-material/Assessment';
import SettingsIcon from '@mui/icons-material/Settings';
import AdministrationIcon from '@mui/icons-material/SupervisorAccount';

const icons = {
  administration: AdministrationIcon,
  configuration: SettingsIcon,
  home: HomeIcon,
  monitoring: MonitoringIcon,
  reporting: ReportingIcon
};

export default icons;
